==> kubernetes-model-gatewayapi-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GRPCRouteFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GRPCRouteFluent<A extends GRPCRouteFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public GRPCRouteFluent.MetadataNested<A> withNewMetadata();
  public GRPCRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public GRPCRouteFluent.MetadataNested<A> editMetadata();
  public GRPCRouteFluent.MetadataNested<A> editOrNewMetadata();
  public GRPCRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GRPCRouteSpec getSpec();
  public GRPCRouteSpec buildSpec();
  public A withSpec(GRPCRouteSpec spec);
  public Boolean hasSpec();
  public GRPCRouteFluent.SpecNested<A> withNewSpec();
  public GRPCRouteFluent.SpecNested<A> withNewSpecLike(GRPCRouteSpec item);
  public GRPCRouteFluent.SpecNested<A> editSpec();
  public GRPCRouteFluent.SpecNested<A> editOrNewSpec();
  public GRPCRouteFluent.SpecNested<A> editOrNewSpecLike(GRPCRouteSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GRPCRouteStatus getStatus();
  public GRPCRouteStatus buildStatus();
  public A withStatus(GRPCRouteStatus status);
  public Boolean hasStatus();
  public GRPCRouteFluent.StatusNested<A> withNewStatus();
  public GRPCRouteFluent.StatusNested<A> withNewStatusLike(GRPCRouteStatus item);
  public GRPCRouteFluent.StatusNested<A> editStatus();
  public GRPCRouteFluent.StatusNested<A> editOrNewStatus();
  public GRPCRouteFluent.StatusNested<A> editOrNewStatusLike(GRPCRouteStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<GRPCRouteFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,GRPCRouteSpecFluent<GRPCRouteFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,GRPCRouteStatusFluent<GRPCRouteFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GRPCRouteFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GRPCRouteFluent<A extends GRPCRouteFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public GRPCRouteFluent.MetadataNested<A> withNewMetadata();
  public GRPCRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public GRPCRouteFluent.MetadataNested<A> editMetadata();
  public GRPCRouteFluent.MetadataNested<A> editOrNewMetadata();
  public GRPCRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GRPCRouteSpec getSpec();
  public GRPCRouteSpec buildSpec();
  public A withSpec(GRPCRouteSpec spec);
  public Boolean hasSpec();
  public GRPCRouteFluent.SpecNested<A> withNewSpec();
  public GRPCRouteFluent.SpecNested<A> withNewSpecLike(GRPCRouteSpec item);
  public GRPCRouteFluent.SpecNested<A> editSpec();
  public GRPCRouteFluent.SpecNested<A> editOrNewSpec();
  public GRPCRouteFluent.SpecNested<A> editOrNewSpecLike(GRPCRouteSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GRPCRouteStatus getStatus();
  public GRPCRouteStatus buildStatus();
  public A withStatus(GRPCRouteStatus status);
  public Boolean hasStatus();
  public GRPCRouteFluent.StatusNested<A> withNewStatus();
  public GRPCRouteFluent.StatusNested<A> withNewStatusLike(GRPCRouteStatus item);
  public GRPCRouteFluent.StatusNested<A> editStatus();
  public GRPCRouteFluent.StatusNested<A> editOrNewStatus();
  public GRPCRouteFluent.StatusNested<A> editOrNewStatusLike(GRPCRouteStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<GRPCRouteFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,GRPCRouteSpecFluent<GRPCRouteFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,GRPCRouteStatusFluent<GRPCRouteFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
